@@ -103,7 +103,7 @@ class DocumentMetaclass(type):
 
         attrs['_fields_ordered'] = tuple(i[1] for i in sorted(
                                          (v.creation_counter, v.name)
-                                         for v in doc_fields.values()))
+                                         for v in iter(doc_fields.values())))
 
         #
         # Set document hierarchy
