@@ -193,7 +193,10 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
 
             # Ensure indexes on the collection unless auto_create_index was
             # set to False.
-            if cls._meta.get('auto_create_index', True):
+            # Also there is no need to ensure indexes on slave.
+            db = cls._get_db()
+            if cls._meta.get('auto_create_index', True) and\
+                    db.client.is_primary:
                 cls.ensure_indexes()
 
         return cls._collection
@@ -577,7 +580,7 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
         """Delete the :class:`~mongoengine.Document` from the database. This
         will only take effect if the document has been previously saved.
 
-        :parm signal_kwargs: (optional) kwargs dictionary to be passed to
+        :param signal_kwargs: (optional) kwargs dictionary to be passed to
             the signal calls.
         :param write_concern: Extra keyword arguments are passed down which
             will be used as options for the resultant
@@ -703,7 +706,6 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
             obj = obj[0]
         else:
             raise self.DoesNotExist('Document does not exist')
-
         for field in obj._data:
             if not fields or field in fields:
                 try:
@@ -711,7 +713,7 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
                 except (KeyError, AttributeError):
                     try:
                         # If field is a special field, e.g. items is stored as _reserved_items,
-                        # an KeyError is thrown. So try to retrieve the field from _data
+                        # a KeyError is thrown. So try to retrieve the field from _data
                         setattr(self, field, self._reload(field, obj._data.get(field)))
                     except KeyError:
                         # If field is removed from the database while the object
@@ -719,7 +721,9 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
                         # i.e. obj.update(unset__field=1) followed by obj.reload()
                         delattr(self, field)
 
-        self._changed_fields = obj._changed_fields
+        self._changed_fields = list(
+            set(self._changed_fields) - set(fields)
+        ) if fields else obj._changed_fields
         self._created = False
         return self
 
@@ -965,8 +969,16 @@ class Document(BaseDocument, metaclass=TopLevelDocumentMetaclass):
         """
 
         required = cls.list_indexes()
-        existing = [info['key']
-                    for info in list(cls._get_collection().index_information().values())]
+
+        existing = []
+        for info in list(cls._get_collection().index_information().values()):
+            if '_fts' in info['key'][0]:
+                index_type = info['key'][0][1]
+                text_index_fields = list(info.get('weights').keys())
+                existing.append(
+                    [(key, index_type) for key in text_index_fields])
+            else:
+                existing.append(info['key'])
         missing = [index for index in required if index not in existing]
         extra = [index for index in existing if index not in required]
 
@@ -1010,6 +1022,7 @@ class DynamicDocument(Document, metaclass=TopLevelDocumentMetaclass):
         field_name = args[0]
         if field_name in self._dynamic_fields:
             setattr(self, field_name, None)
+            self._dynamic_fields[field_name].null = False
         else:
             super(DynamicDocument, self).__delattr__(*args, **kwargs)
 
